
GGCE
====

.. image:: https://codecov.io/gh/x94carbone/GGCE/branch/master/graph/badge.svg?token=6Q7EUWBW6O
   :target: https://codecov.io/gh/x94carbone/GGCE
   :alt: codecov


Generalized Green's function Cluster Expansion

Installation
------------

We provide detailed information on how to install the GGCE package in our documentation (link TK).

Acknowledgements
----------------

.. inclusion-marker-acknowledgements-begin

This material is based upon work supported by the U.S. Department of Energy, Office of Science, Office of Advanced Scientific Computing Research, Department of Energy Computational Science Graduate Fellowship under Award Number DE-FG02-97ER25308. This work also used theory and computational resources of the Center for Functional Nanomaterials, which is a U.S. Department of Energy Office of Science User Facility, and the Scientific Data and Computing Center, a component of the Computational Science Initiative, at Brookhaven National Laboratory under Contract No. DE-SC0012704.

.. inclusion-marker-acknowledgements-end


Citation
--------

If you use this software, please cite our JOSS manuscript **(JOSS manuscript currently in prep)**.

If you make references to the theory or application of the GGCE methodology, please consider citing the following two manuscripts: `Carbone, Reichman et al. <https://journals.aps.org/prb/abstract/10.1103/PhysRevB.104.035106>`__ and `Carbone, Millis et al <https://journals.aps.org/prb/abstract/10.1103/PhysRevB.104.L140307>`__:

.. code-block::

   @article{carbone2021,
     title={Numerically exact generalized Green's function cluster expansions for electron-phonon problems},
     author={Carbone, Matthew R and Reichman, David R and Sous, John},
     journal={Phys. Rev. B.},
     volume={104},
     number={3},
     pages={035106},
     year={2021},
     publisher={APS}
   }

   @article{carbone2021bond,
     title={Bond-Peierls polaron: Moderate mass enhancement and current-carrying ground state},
     author={Carbone, Matthew R and Millis, Andrew J and Reichman, David R and Sous, John},
     journal={Phys. Rev. B.},
     volume={104},
     number={14},
     pages={L140307},
     year={2021},
     publisher={APS}
   }
